@@ -2,7 +2,7 @@
 
 import inspect
 import re
-from typing import Any, Callable, Optional, Set, Type, Union
+from typing import Any, Callable, List, Optional, Set, Type, Union
 
 from .actions import _ActionConfigLoad, _ActionHelpClassPath
 from .typehints import ActionTypeHint, is_optional
@@ -36,7 +36,8 @@ class SignatureArguments:
         as_positional: bool = False,
         skip: Optional[Set[str]] = None,
         fail_untyped: bool = True,
-    ) -> int:
+        sub_configs: bool = False,
+    ) -> List[str]:
         """Adds arguments from a class based on its type hints and docstrings.
 
         Note: Keyword arguments without at least one valid type are ignored.
@@ -48,9 +49,10 @@ class SignatureArguments:
             as_positional: Whether to add required parameters as positional arguments.
             skip: Names of parameters that should be skipped.
             fail_untyped: Whether to raise exception if a required parameter does not have a type.
+            sub_configs: Whether subclass type hints should be loadable from inner config file.
 
         Returns:
-            Number of arguments added.
+            The list of arguments added.
 
         Raises:
             ValueError: When not given a class.
@@ -65,8 +67,9 @@ class SignatureArguments:
                                              as_positional,
                                              skip,
                                              fail_untyped,
-                                             get_class_init_and_base_docstrings,
-                                             get_class_init,
+                                             sub_configs=sub_configs,
+                                             docs_func=get_class_init_and_base_docstrings,
+                                             sign_func=get_class_init,
                                              skip_first=True)
 
 
@@ -79,7 +82,8 @@ class SignatureArguments:
         as_positional: bool = False,
         skip: Optional[Set[str]] = None,
         fail_untyped: bool = True,
-    ) -> int:
+        sub_configs: bool = False,
+    ) -> List[str]:
         """Adds arguments from a class based on its type hints and docstrings.
 
         Note: Keyword arguments without at least one valid type are ignored.
@@ -92,9 +96,10 @@ class SignatureArguments:
             as_positional: Whether to add required parameters as positional arguments.
             skip: Names of parameters that should be skipped.
             fail_untyped: Whether to raise exception if a required parameter does not have a type.
+            sub_configs: Whether subclass type hints should be loadable from inner config file.
 
         Returns:
-            Number of arguments added.
+            The list of arguments added.
 
         Raises:
             ValueError: When not given a class or the name of a method of the class.
@@ -114,6 +119,7 @@ class SignatureArguments:
                                              as_positional,
                                              skip,
                                              fail_untyped,
+                                             sub_configs=sub_configs,
                                              skip_first=skip_first)
 
 
@@ -125,7 +131,8 @@ class SignatureArguments:
         as_positional: bool = False,
         skip: Optional[Set[str]] = None,
         fail_untyped: bool = True,
-    ) -> int:
+        sub_configs: bool = False,
+    ) -> List[str]:
         """Adds arguments from a function based on its type hints and docstrings.
 
         Note: Keyword arguments without at least one valid type are ignored.
@@ -137,9 +144,10 @@ class SignatureArguments:
             as_positional: Whether to add required parameters as positional arguments.
             skip: Names of parameters that should be skipped.
             fail_untyped: Whether to raise exception if a required parameter does not have a type.
+            sub_configs: Whether subclass type hints should be loadable from inner config file.
 
         Returns:
-            Number of arguments added.
+            The list of arguments added.
 
         Raises:
             ValueError: When not given a callable.
@@ -153,7 +161,8 @@ class SignatureArguments:
                                              as_group,
                                              as_positional,
                                              skip,
-                                             fail_untyped)
+                                             fail_untyped,
+                                             sub_configs=sub_configs)
 
 
     def _add_signature_arguments(
@@ -164,10 +173,11 @@ class SignatureArguments:
         as_positional: bool,
         skip: Optional[Set[str]],
         fail_untyped: bool,
+        sub_configs: bool = False,
         docs_func: Callable = lambda x: [x.__doc__],
         sign_func: Callable = lambda x: x,
         skip_first: bool = False,
-    ) -> int:
+    ) -> List[str]:
         """Adds arguments from parameters of objects based on signatures and docstrings.
 
         Args:
@@ -177,12 +187,13 @@ class SignatureArguments:
             as_positional: Whether to add required parameters as positional arguments.
             skip: Names of parameters that should be skipped.
             fail_untyped: Whether to raise exception if a required parameter does not have a type.
+            sub_configs: Whether subclass type hints should be loadable from inner config file.
             docs_func: Function that returns docstrings for a given object.
             sign_func: Function that returns signature method for a given object.
             skip_first: Whether to skip first argument, i.e., skip self of class methods.
 
         Returns:
-            Number of arguments added.
+            The list of arguments added.
 
         Raises:
             ValueError: When there are required parameters without at least one valid type.
@@ -211,7 +222,7 @@ class SignatureArguments:
         group = self._create_group_if_requested(objects[0], nested_key, as_group, doc_group)
 
         ## Add objects arguments ##
-        added_args = set()  # type: Set[str]
+        added_args = []  # type: List[str]
         if skip is None:
             skip = set()
         for obj, (add_args, add_kwargs) in zip(objects, add_types):
@@ -227,12 +238,13 @@ class SignatureArguments:
                     added_args,
                     skip,
                     fail_untyped=fail_untyped,
+                    sub_configs=sub_configs,
                     as_positional=as_positional,
                     add_args=add_args,
                     add_kwargs=add_kwargs,
                 )
 
-        return len(added_args)
+        return added_args
 
 
     def _add_signature_parameter(
@@ -242,10 +254,11 @@ class SignatureArguments:
         param,
         obj: Type,
         doc_params: dict,
-        added_args: Set[str],
+        added_args: List[str],
         skip: Set[str],
         fail_untyped: bool = True,
         as_positional: bool = False,
+        sub_configs: bool = False,
         add_args: bool = True,
         add_kwargs: bool = True,
         default: Any = inspect_empty,
@@ -292,8 +305,9 @@ class SignatureArguments:
             kwargs['type'] = annotation
         elif annotation != inspect_empty:
             try:
-                kwargs['action'] = ActionTypeHint(typehint=annotation)
                 is_subclass_typehint = ActionTypeHint.is_subclass_typehint(annotation)
+                enable_path = is_subclass_typehint and sub_configs
+                kwargs['action'] = ActionTypeHint(typehint=annotation, enable_path=enable_path)
             except ValueError as ex:
                 self.logger.debug(skip_message+str(ex))  # type: ignore
         if 'type' in kwargs or 'action' in kwargs:
@@ -307,9 +321,13 @@ class SignatureArguments:
                     init = name + '.init_args.'
                     subclass_skip = {s[len(init):] for s in skip if s.startswith(init)}
                 action = group.add_argument(opt_str, **kwargs)
+                action.sub_add_kwargs = {
+                    'fail_untyped': fail_untyped,
+                    'sub_configs': sub_configs,
+                }
                 if is_subclass_typehint and len(subclass_skip) > 0:
-                    action.skip = subclass_skip
-                added_args.add(dest)
+                    action.sub_add_kwargs['skip'] = subclass_skip
+                added_args.append(dest)
         elif is_required and fail_untyped:
             raise ValueError('Required parameter without a type for '+obj.__name__+' parameter '+name+'.')
 
@@ -321,7 +339,7 @@ class SignatureArguments:
         default: Union[Type, dict] = None,
         as_group: bool = True,
         **kwargs
-    ):
+    ) -> List[str]:
         """Adds arguments from a dataclass based on its field types and docstrings.
 
         Args:
@@ -331,7 +349,7 @@ class SignatureArguments:
             as_group: Whether arguments should be added to a new argument group.
 
         Returns:
-            Number of arguments added.
+            The list of arguments added.
 
         Raises:
             ValueError: When not given a dataclass.
@@ -358,7 +376,7 @@ class SignatureArguments:
                 raise ValueError('Expected "default" argument to be an instance of "'+theclass.__name__+'" or its kwargs dict, given '+str(default))
             defaults = dataclasses.asdict(default)
 
-        added_args = set()  # type: Set[str]
+        added_args = []  # type: List[str]
         skip = set()  # type: Set[str]
         params = inspect.signature(theclass.__init__).parameters
         for field in dataclasses.fields(theclass):
@@ -373,7 +391,7 @@ class SignatureArguments:
                 default=defaults.get(field.name, inspect_empty),
             )
 
-        return len(added_args)
+        return added_args
 
 
     def add_subclass_arguments(
